// Persistence of Vision Ray Tracer Scene Description File
//        File: cube4e.pov
//      Povray: linux: povray self compiled; There are not modifications on the source files I have made.
//              winXp: povray-instllaller from www.povray.org webseite
//     version: 3.6.1 (on win32/linux)
//          OS: Linux Suse9.1 / kernel 2.6.8.1 (SMP)
//          OS: WinXP + SP1
//         CPU: intel pentium iv  (3.06 MHz incl. hyper threading)
//         mem: 1 GB 
//    harddisc: ide (80GB) 
// render time: 
//
//        desc: a transparent cube - with drillings on each plane
//     created: 04. Januar 2002
//     updated: 16. Januar 2005
//      author: Tilo Helmig <tilo.helmig@gmx.de>;  Munich; Germany
//                             
//  1280/5=256  and  960/5=192   
//     based on this the area has a size of 1/25th of the whole picture
//
//   Option:    +FP
//  Zoom 1: 735x093 - 256x192  (+SC +SR  +EC +ER)
//       2: 511x551 - 256x192  (+SC2550 +SR2750  +EC3830 +ER3710)
//       3: 750x000 - 256x192  (+SC3750 +SR0001  +EC5030 +ER0960)
//       4: 710x055 - 256x192  (+SC3710 +SR0051  +EC4990 +ER1010)
//
// Do you need a animation? Hopefully you have enought time
// together with a powerfull computer to do this :-)

/*
 tip: if you rotate the whole main object without clipping anything
      you can set Final_Clock to 0.25 alias 90 degree!

Clock=0.0
Initial_Frame=1
Final_Frame=720     // a greater value is better for a smoother movie
Initial_Clock=0.0
Final_Clock=1.0	    // 360 degrees or a complete rotation
// Final_Clock=0.25
  Subset_Start_Frame=20
  Subset_End_Frame=30	
*/

#version 3.5;
                                        
// === Standard POV-Ray Includes ===
#include "colors.inc"	
#include "textures.inc"	
#include "metals.inc"	
#include "finish.inc"	
#include "shapes.inc"
          
// === Konstanten ===
#declare  LICHTFARBE    = <0.8, 0.8, 0.8>;
#declare  MAX_TRACE_LVL =  9;
#declare  TARGET =  <-0.5, 0, 0>;
#declare  HINTERGRUND = MediumSeaGreen; 
#declare  SPOT_RADIUS  =   1.0;
#declare  SPOT_FALLOFF =  20.0; 


// *** colors and things like this       
#declare tex_Wand = texture {
    pigment { MediumSeaGreen }
    finish {
        ambient 0.0
        diffuse 0.8
        reflection 0.33
    }
}

#declare tex_cRGB = 0.98;
#declare tex_CUBE1 = texture {
    pigment { 
        color rgbft <tex_cRGB, tex_cRGB, tex_cRGB, 0.8, 0>  // 4. Filter 5: Transmit 
    }
    finish {
        ambient 0  
        diffuse 0  
        reflection 0.375
        phong 1.0
        phong_size 200        
        specular 0.66
    }
}

#declare tex_CUBE2 = texture {
    pigment { P_Copper4 * 0.75 }
    finish
    {
        reflection 0.33
        roughness 1/80
        metallic
    }
}

#declare ior_CUBE = interior { 
  ior 1.42 
  dispersion 1.3102 
  caustics 2
  fade_distance 1.5
  fade_power 1
}
         

// *** globals ***
global_settings { 
    assumed_gamma 2.2 
    max_trace_level  MAX_TRACE_LVL
    adc_bailout 0.02    
    photons { spacing 0.01 }    
}         

camera {  
    direction <0, 0, 1.5>
    up        <0, 1, 0>
    right     <4/3, 0, 0>
    location  <-5, 6, -12> * 0.8   // das Bild
    //   location  <0, 12, 0>  // ortho-oben
    //   location  <0, 1, 12>  // ortho-vorn
    look_at   TARGET
}

background { color HINTERGRUND }

// *** spot lights (3x) ***
// light from left 
light_source {   
    <-10, 10, -10>
    color  LICHTFARBE 
    spotlight    point_at  TARGET    falloff  SPOT_FALLOFF    radius  SPOT_RADIUS
}

// light from right
light_source {   
    <+7, 10, -10>
    color  LICHTFARBE 
    spotlight    point_at  TARGET    falloff SPOT_FALLOFF    radius  SPOT_RADIUS
}

// backlight 
light_source {   
    <-2, 20, 15>
    color  LICHTFARBE * 0.49
    spotlight    point_at  TARGET    falloff SPOT_FALLOFF    radius  SPOT_RADIUS
}



// the floor
#declare  Boden = object {  
    plane { y, 0.0                 
        photons { target 1.0  refraction on   reflection on  collect on  }
        texture { tex_Wand }
    }
}  

// for the look of light on all objects
sky_sphere {
    pigment {
        gradient y    
        color_map {[0, 1  color Gray30 color Gray80]}
        rotate x*30
    }
}


// construction tool, not for the final rendering process
#declare AxisRadius = 0.04; 
#declare AxisLaenge = 5;
#declare Axis = object {
    union {  
        cylinder{ <0,0,0>, <0,AxisLaenge,0>,  AxisRadius texture { pigment { rgb <1,0,0> } } }
        cylinder{ <0,0,0>, <AxisLaenge,0,0>,  AxisRadius texture { pigment { rgb <0,1,0> } } }
        cylinder{ <0,0,0>, <0,0,-AxisLaenge>, AxisRadius texture { pigment { rgb <0,0,1> } } }
    }
}

#declare tex_CUBE = tex_CUBE1
#declare SQR2= 1.41423562;
#declare SQR3= 1.73205080;

#declare RATIO_RAD= 1/12;
#declare RATIO_LEN= 1/5;

#declare L1 = 1.00;
#declare L0 = 1.00;
#declare LC = 0.01+L0; 
#declare gesZoom = 1.50;

#declare picNr = clock*(90.0/180);
#debug concat("       clock: ", str(clock,6,4)," #",str( (clock*360.0),4,0), "\n")
#debug concat("   recursion: ", str(MAX_TRACE_LVL,6,0), "\n")
#debug concat("ratio radius: ", str(RATIO_RAD,6,4), "\n")
#debug concat("ratio len   : ", str(RATIO_LEN,6,4), "\n")


#declare theCUBE = object {
    merge {
        #declare loopIdx=0;
#while (L0>0.1)                                                       
        
        #declare RADIUS         = L0-(L0*RATIO_RAD);  
        #declare CONEPHASE      = RADIUS * 0.075;   
        #declare CONEBASE_RADIUS= RADIUS - CONEPHASE;
        #declare CONECAP_RADIUS = RADIUS + CONEPHASE;
        #declare CONEBASE_POS   = LC - (CONEPHASE/2.0);
        #declare CONECAP_POS    = LC + (CONEPHASE/2.0);
        #declare RADIUS         = RADIUS- (CONEPHASE*0.75);  
        
        #debug concat("Idx:", str(loopIdx,2,0), ". L0:", str(L0,6,4),"  R:", str(RADIUS,6,4)," Phase:",str(CONEPHASE,6,4), "\n")
    
        difference { 
            object { 
                superellipsoid { <0.11, 0.11> scale <L0,L0,L0> }
                photons { target 1.0  refraction on   reflection on  collect on  }
            }
            // 1 (Y)
            cylinder {  < 0, -LC,  0>,  <0, LC, 0>,  RADIUS }
            cone { <0, CONEBASE_POS, 0>,  CONEBASE_RADIUS, <0, CONECAP_POS, 0>, CONECAP_RADIUS }
            cone { <0,-CONEBASE_POS, 0>,  CONEBASE_RADIUS, <0,-CONECAP_POS, 0>, CONECAP_RADIUS }
            // 2 (X)
            cylinder {  <-LC,  0,  0>,  <LC, 0, 0>,  RADIUS }
            cone { < CONEBASE_POS, 0, 0>, CONEBASE_RADIUS, < CONECAP_POS, 0, 0>, CONECAP_RADIUS }
            cone { <-CONEBASE_POS, 0, 0>, CONEBASE_RADIUS, <-CONECAP_POS, 0, 0>, CONECAP_RADIUS }
            // 3 (Z)
            cylinder {  < 0,  0, -LC>,  <0, 0, LC>,  RADIUS }   
            cone { <0, 0, CONEBASE_POS>,  CONEBASE_RADIUS, <0, 0, CONECAP_POS>, CONECAP_RADIUS }
            cone { <0, 0,-CONEBASE_POS>,  CONEBASE_RADIUS, <0, 0,-CONECAP_POS>, CONECAP_RADIUS }
        } 
        #declare L0= L0- (L0*RATIO_LEN);
        #declare LC = 0.01+L0; 
        #declare loopIdx=loopIdx+1;
#end
    }
}

// === the visible scene ===
object { Boden translate <0,-1.5, 0> }  
// object { Axis translate <0,0,0> }
object {   
  difference { 
    object { theCUBE }
    object { box { <0,0,0>, <-L1, L1, -L1> } }
  }
  texture { tex_CUBE }
  interior { ior_CUBE }
  rotate <0, (1.0-clock)*360.0, 0>      
  scale <gesZoom, gesZoom, gesZoom>
  translate <0,1,0>
}
object {
  intersection { 
    object { theCUBE }
    object { box { <0,0,0>, <-L1, -L1, -L1> } }
  }
  rotate <0,30,0>
  translate <-1.6, 0,-0.75>
  texture { tex_CUBE }
  interior { ior_CUBE }
  scale <gesZoom, gesZoom, gesZoom>
  translate <0,1,0>
}        
// === End === 

